import { Result as Result$1, Exception as Exception$1 } from '@zxing/library';
import React from 'react';

declare function QrCodeScanner<T = unknown>(props: {
    /**
     * This event gets fired when a qr-code is scanned
     * @param result The result of the qr-code (parsed)
     * @param rawResult The result of the qr-code (raw, this is the result that you got before version 2.0.0)
     */
    onResult: (result: T, rawResult: Result) => void;
    /** This event gets fired when a exception occurs */
    onError?: (error: Exception) => void;
    /**
     * Which mode should the scanner face
     * @default "environment"
     */
    facingMode?: "environment" | "user";
    /** Validate the qr codes data */
    validate?: (data: unknown) => T;
}): React.JSX.Element;

/** The type that the on result event returns */
type Result = Result$1;
/** The type that the on exception event returns */
type Exception = Exception$1;

export { Exception, QrCodeScanner, Result };
